@@ -1,4 +1,4 @@
-from ._dispatcher import Dispatcher
+from ._dispatcher import Dispatcher, Subscriber
 from ._exc_info import ExcInfo
 from ._lifecycle import Lifecycle
 from ._plugin import Plugin
@@ -7,11 +7,12 @@ from ._runner import Runner
 from ._scenario_discoverer import ScenarioDiscoverer
 from ._scenario_finder import ScenarioFinder
 from ._scenario_loader import ScenarioLoader
-from ._scenario_result import ScenarioResult
-from ._step_result import StepResult
+from ._scenario_result import ScenarioResult, ScenarioStatus
+from ._step_result import StepResult, StepStatus
 from ._virtual_scenario import VirtualScenario
 from ._virtual_step import VirtualStep
 
-__all__ = ("Dispatcher", "ExcInfo", "Lifecycle", "Plugin", "Report", "Runner",
+__all__ = ("Dispatcher", "Subscriber", "ExcInfo", "Lifecycle", "Plugin", "Report", "Runner",
            "ScenarioDiscoverer", "ScenarioFinder", "ScenarioLoader",
-           "ScenarioResult", "StepResult", "VirtualScenario", "VirtualStep",)
+           "ScenarioResult", "StepResult", "VirtualScenario", "VirtualStep",
+           "ScenarioStatus", "StepStatus",)
