@@ -1,6 +1,7 @@
 from ._director import Director
 from ._reporter import Reporter
+from .pycharm import PyCharmReporter
 from .rich import RichReporter
 from .silent import SilentReporter
 
-__all__ = ("Director", "Reporter", "RichReporter", "SilentReporter",)
+__all__ = ("Director", "Reporter", "RichReporter", "SilentReporter", "PyCharmReporter",)
